'CueExport.vbs, CUESheet File Export Script By Peke (Sept-14-2004)
'
' Edit Scripts.ini and add this
'---------------------------------------
'[ExportCUE]
'DisplayName=Export to &CUE
'Description=Export Selected to CUESheet
'FileName=CueExport.vbs
'ProcName=ExportCUE
'Order=5
'ScriptType=1
'Language=VBScript
'---------------------------------------
' Note: After Export is done Edit exported CUEFile as first two
'       lines represents CD-Text CD Title and Artist names.
'       This will possibly be Automated in future versions


Option Explicit     ' report undefined variables, ...

' function for quoting strings
Function QStr( astr)
  QStr = chr(34) & astr & chr(34)
End Function

Dim list      ' list of songs to be exported
Dim res       ' results of dialogs calls
Dim fullfile  ' fully specified output file name
Dim fso       ' FileSystemObject

' SDB variable is connected to MediaMonkey application object

Sub InitExport( ext, filter, iniDirValue)
  fullfile = ""

  ' Get a list of songs to be exported
  Set list = SDB.SelectedSongList
  If list.count=0 Then
    Set list = SDB.AllVisibleSongList
  End If

  If list.count=0 Then
    res = SDB.MessageBox( SDB.Localize("Select tracks to be exported, please."), mtError, Array(mbOk))
    Exit Sub
  End If

  ' check for Audio CD 99 Track Limitation
  If list.count > 99 Then
    res = SDB.MessageBox( SDB.Localize("CUESheet is limited to 99 Tracks"), mtError, Array(mbOk))
    Exit Sub
  end if


  ' Open inifile and get last used directory
  Dim iniF
  Set iniF = SDB.IniFile

  ' Create common dialog and ask where to save the file
  Dim dlg
  Set dlg = SDB.CommonDialog
  dlg.DefaultExt=ext
  dlg.Filter=filter
  dlg.Flags=cdlOFNOverwritePrompt + cdlOFNHideReadOnly
  dlg.InitDir = iniF.StringValue( "Scripts", iniDirValue)
  dlg.ShowSave

  if Not dlg.Ok Then
    Exit Sub   ' if cancel was pressed, exit
  End If

  ' Get the selected filename
  fullfile = dlg.FileName

  ' Connect to the FileSystemObject
  Set fso = CreateObject("Scripting.FileSystemObject")

  ' Write selected directory to the ini file
  iniF.StringValue( "Scripts", iniDirValue) = fullfile
End Sub

Sub FinishExport( ok)
  On Error Resume Next

  ' remove the output file if terminated
  if not Ok then
    fso.DeleteFile( fullfile)
  end if
End Sub

Sub ExportCUE
  ' initialize export
  Call InitExport (".cue", "CUESheet (*.cue)|*.cue|All files (*.*)|*.*", _
      "LastExportCUEDir")
  if fullfile="" then
    Exit Sub
  end if

  ' Create the output file
  Dim fout
  Set fout = fso.CreateTextFile( fullfile, True)

  ' Use progress to notify user about the current action
  Dim Progress
  Set Progress = SDB.Progress
  Progress.Text = SDB.Localize("Exporting...")

  ' Iterate through the list and export all songs
  Progress.MaxValue = list.count
  Dim i, itm, Track, Ttype, found
  Track = 1
  ' This is CUESheet File Comment
  fout.WriteLine "REM This CUESheet File was written with MediaMonkey ExportScript By Peke"
  ' This Writes CD Title to CUESheet
  fout.WriteLine "TITLE "&qstr("CD Title")
  ' This Writes CD Artist to CUESheet
  fout.WriteLine "PERFORMER "&qstr("CD Artist")
  for i=0 to list.count-1
    found = False
    Set itm = list.Item(i)
    Dim Filename, Ftype, Ftitle, Fartist, Flyricist, Fisrc 
    If itm.Cached = 1 then
      Filename = itm.CachedPath
      If Left(right(Filename,4),1) = "." Then
        Ftype = right(filename,3)
      else
        Ftype = right(Filename,4)
      end if
      faund = True
    else
      Filename = itm.Path
      If Left(Filename,1) = "?" Then
        Progress.Value = i+1
        found = False
      Else
        If Left(right(Filename,4),1) = "." Then
          Ftype = Ucase(right(filename,3))
        else
          Ftype = Ucase(right(Filename,4))
        end if
        found = True
      end if
    end if
    If found then
      Ftitle = itm.Title
      Fartist = itm.ArtistName
      Flyricist = itm.lyricist
      Fisrc = itm.ISRC
      Ttype = 0
      ' This detirmates Track Type as CUE only Support MP3 and WAVE Audio Types for Track
      If Ftype = "MP3" Then
        Ttype = 1
      end if
      If Ftype = "WAV" Then
        Ttype = 2
      end if
      if ttype > 0 then
        If ttype = 1 Then
         ' This Writes Track filename to CUESheet
          fout.WriteLine "  FILE "&qstr(filename)&" MP3"
        End if
        if ttype = 2 Then
          fout.WriteLine "  FILE "&qstr(filename)&" WAVE"
        end if
        ' This Writes Track Number and type to CUESheet
        fout.WriteLine "  TRACK "&cstr(track)&" AUDIO"
        If FTitle <> "" Then
         ' This Writes Track Title to CUESheet
          fout.WriteLine "    TITLE "&qstr(SDB.toASCII(Ftitle))
        end if
        If FArtist <> "" Then
         ' This Writes Track Artist to CUESheet
          fout.WriteLine "    PERFORMER "&qstr(SDB.toASCII(FArtist))
        end if
        If Flyricist <> "" Then
         ' This Writes Track Lyricist to CUESheet
          fout.WriteLine "    LYRICIST "&qstr(SDB.toASCII(Flyricist))
        end if
        if fIsrc <> "" then
         ' This Writes Track ISRC to CUESheet
          fout.WriteLine "    ISRC "&fIsrc
        end if
        ' This Writes Track Start time to CUESheet
        fout.WriteLine "    INDEX 01 00:00:00"
      End if
      track = track+1
    End if
    Progress.Value = i+1
    if Progress.Terminate then
      Exit For
    end if
  next

  ' Close the output file and finish
  fout.Close

  ' Was it successfull?
  Dim ok
  if Progress.Terminate then
    ok = False
  else
    ok = True
  end if

  ' hide progress
  Set Progress = Nothing

  Call FinishExport( ok)
End Sub
